@@ -6,18 +6,20 @@ from .firewall_template import FirewallTemplate
 from .firewall_template_rule import FirewallTemplateRule
 from .hypervisor import Hypervisor
 from .lbaas import Lbaas
-from .lbaas_pool import LbaasPool
+from .lbaas_pool import LbaasPool, LbaasPoolMember
 from .manager import Manager
 from .network import Network
-from .port import Port
+from .port import ConnectedObject, Port
 from .project import Project
 from .router import Router
+from .snapshot import Snapshot
 from .storage_profile import StorageProfile
 from .subnet import Subnet
 from .template import Template
 from .template_field import TemplateField
+from .user import Domain, DomainAlias, User
 from .vdc import Vdc
 from .vm import Vm
 from .vm_metadata import VmMetadata
 
-__version__ = '0.1.7'
+__version__ = '0.1.10'
